Learn R Programming

geometa (version 0.10.0)

ISODataQualityScope: ISODataQualityScope

Description

ISODataQualityScope

ISODataQualityScope

Arguments

Value

Object of R6Class for modelling an ISO Scope

Format

R6Class object.

Author

Emmanuel Blondel <emmanuel.blondel1@gmail.com>

Super classes

geometa::geometaLogger -> geometa::ISOAbstractObject -> ISODataQualityScope

Public fields

level

level

Methods

Inherited methods


Method new()

Initializes object

Usage

ISODataQualityScope$new(xml = NULL)

Arguments

xml

object of class XMLInternalNode-class


Method setLevel()

Set level

Usage

ISODataQualityScope$setLevel(level)

Arguments

level

object of class ISOScopeCode or any character among values returned by ISOScopeCode


Method clone()

The objects of this class are cloneable with this method.

Usage

ISODataQualityScope$clone(deep = FALSE)

Arguments

deep

Whether to make a deep clone.

Examples

Run this code
  md <- ISODataQualityScope$new()
  md$setLevel("dataset")
  xml <- md$encode()

Run the code above in your browser using DataLab