powered by
registerISOCodelist allows to register a new codelist registered in geometa
registerISOCodelist
registerISOCodelist(refFile, id, force)
ISO XML file handling the ISO codelist
identifier of the ISO codelist
logical parameter indicating if registration has be to be forced in case the identified codelist is already registered
# NOT RUN { registerISOCodelist( refFile = "http://www.isotc211.org/2005/resources/Codelist/ML_gmxCodelists.xml", id = "LanguageCode", force = TRUE ) # }
Run the code above in your browser using DataLab